package com.softcream.archosx.dicomparser;

import com.pixelmed.dicom.*;
import com.pixelmed.display.SourceImage;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;

/**
 * ArchOSx™ tool DIKOCM Parser copyright (C) 2020 SoftCream Software, Ltd - All Rights Reserved
 * PixelMed™ Java DICOM Toolkit copyright (C)The toolkit is open source and made freely available for both non-commercial and commercial use, under BSD License terms described here https://www.pixelmed.com/
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by:
 * Robert Smietanka robert@softcream.pl
 *
 * @param  filename the name  of the DICOM file to parse
 * @return the data file
 */


public class DicomParser {

    public FileList fileList = new FileList();
    public AttributeList attributeList;
    public String filename;


    public DicomParser() {
        this.fileList=fileList;
        this.attributeList= new AttributeList();
        this.filename =  filename;
    }

    public DicomParser(String filename){
        this.filename=filename;
        this.attributeList= new AttributeList();
        this.filename =  filename;
    }

     void parseAllDicomFilesAndSaveDataToFiles()  {

        int i = 0;
        try {
            while (i < fileList.getFiles().size()) {
                attributeList.read(fileList.getFileName(i));

               SourceImage img = new com.pixelmed.display.SourceImage(attributeList);

                File datafile = new File(fileList.getFileName(i)+".txt");
                FileWriter fr = new FileWriter(datafile, false);
                BufferedWriter br = new BufferedWriter(fr);
                br.write("File name: " + fileList.getFileName(i)+"\n");
                br.write("Patient Name: " + getTagInformation(TagFromName.PatientName) + "\n");
                br.write("Patient ID: " + getTagInformation(TagFromName.PatientID) + "\n");
                br.write("Patient Age: " + getTagInformation(TagFromName.PatientAge) + "\n");
                br.write("Patient Breed Code Sequence: " + getTagInformation(TagFromName.PatientBreedCodeSequence) + "\n");
                br.write("Patient Breed Description: " + getTagInformation(TagFromName.PatientBreedDescription) + "\n");
                br.write("Patient comments: " + getTagInformation(TagFromName.PatientComments) + "\n");
                br.write("Patient sex: " + getTagInformation(TagFromName.PatientSex) + "\n");
                br.write("Patient address: " + getTagInformation(TagFromName.PatientAddress) + "\n");
                br.write("Transfer Syntax: " + getTagInformation(TagFromName.TransferSyntaxUID) + "\n");
                br.write("SOP Class: " + getTagInformation(TagFromName.SOPClassUID) + "\n");
                br.write("Modality: " + getTagInformation(TagFromName.Modality) + "\n");
                br.write("Samples Per Pixel: " + getTagInformation(TagFromName.SamplesPerPixel) + "\n");
                br.write("Photometric Interpretation: " + getTagInformation(TagFromName.PhotometricInterpretation) + "\n");
                br.write("Pixel Spacing: " + getTagInformation(TagFromName.PixelSpacing) + "\n");
                br.write("Bits Allocated: " + getTagInformation(TagFromName.BitsAllocated) + "\n");
                br.write("Bits Stored: " + getTagInformation(TagFromName.BitsStored) + "\n");
                br.write("High Bit: " + getTagInformation(TagFromName.HighBit) + "\n");
                br.write("Number of frames: " + img.getNumberOfFrames() + "\n");
                br.write("Width: " + img.getWidth() + "\n");// all frames will have same width
                br.write("Height: " + img.getHeight() + "\n");// all frames will have same height
                br.write("Is Grayscale?: " + img.isGrayscale() + "\n");
                br.write("Pixel Data present: " + (attributeList.get(TagFromName.PixelData) != null) + "\n");
                br.write("Operators name: "+(attributeList.get(TagFromName.OperatorsName)+"\n"));
                ++i;
                attributeList.clear();
                br.close();
                fr.close();
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    void parseIndicatedDicomFileAndSaveDataToOneFile  (String filename) {

        try {
                attributeList.read(filename);
                SourceImage img = new com.pixelmed.display.SourceImage(attributeList);

                File datafile = new File(fileList.getFileDirectory() + File.separator + filename +".txt");
                FileWriter fr = new FileWriter(datafile, true);
                BufferedWriter br = new BufferedWriter(fr);
                br.write("File name: " + filename.toString()+"\n");
                br.write("Patient Name: " + getTagInformation(TagFromName.PatientName) + "\n");
                br.write("Patient ID: " + getTagInformation(TagFromName.PatientID) + "\n");
                br.write("Patient Age: " + getTagInformation(TagFromName.PatientAge) + "\n");
                br.write("Patient Breed Code Sequence: " + getTagInformation(TagFromName.PatientBreedCodeSequence) + "\n");
                br.write("Patient Breed Description: " + getTagInformation(TagFromName.PatientBreedDescription) + "\n");
                br.write("Patient comments: " + getTagInformation(TagFromName.PatientComments) + "\n");
                br.write("Patient sex: " + getTagInformation(TagFromName.PatientSex) + "\n");
                br.write("Patient address: " + getTagInformation(TagFromName.PatientAddress) + "\n");
                br.write("Transfer Syntax: " + getTagInformation(TagFromName.TransferSyntaxUID) + "\n");
                br.write("SOP Class: " + getTagInformation(TagFromName.SOPClassUID) + "\n");
                br.write("Modality: " + getTagInformation(TagFromName.Modality) + "\n");
                br.write("Samples Per Pixel: " + getTagInformation(TagFromName.SamplesPerPixel) + "\n");
                br.write("Photometric Interpretation: " + getTagInformation(TagFromName.PhotometricInterpretation) + "\n");
                br.write("Pixel Spacing: " + getTagInformation(TagFromName.PixelSpacing) + "\n");
                br.write("Bits Allocated: " + getTagInformation(TagFromName.BitsAllocated) + "\n");
                br.write("Bits Stored: " + getTagInformation(TagFromName.BitsStored) + "\n");
                br.write("High Bit: " + getTagInformation(TagFromName.HighBit) + "\n");
                br.write("Number of frames: " + img.getNumberOfFrames() + "\n");
                br.write("Width: " + img.getWidth() + "\n");// all frames will have same width
                br.write("Height: " + img.getHeight() + "\n");// all frames will have same height
                br.write("Is Grayscale?: " + img.isGrayscale() + "\n");
                br.write("Pixel Data present: " + (attributeList.get(TagFromName.PixelData) != null) + "\n");
                br.write("Operators name: "+(attributeList.get(TagFromName.OperatorsName)+"\n"));
              //  ++i;
                attributeList.clear();
                br.close();
                fr.close();

        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    private  String getTagInformation(AttributeTag attrTag) {

        return Attribute.getDelimitedStringValuesOrDefault(attributeList, attrTag, "NOT FOUND");
    }

}
