package com.softcream.archosx.dicomparser;

/**
 * ArchOSx™ tool DIKOCM Parser copyright (C) 2020 SoftCream Software, Ltd - All Rights Reserved
 * PixelMed™ Java DICOM Toolkit copyright (C)The toolkit is open source and made freely available for both non-commercial and commercial use, under BSD License terms described here https://www.pixelmed.com/
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by:
 * Robert Smietanka robert@softcream.pl
 *
 * @see @method displayHelp()
 * Example: DICOM-Parser -a
 * Example: DICOM-Parser test1.dcm
 */

import java.io.*;
import java.util.ArrayList;


public class Main {

    public static void main(String[] args) throws IOException {

        for (String s: args){
            if (s.equals("-h") || s.equals("--help")|| s.equals(""))  {
                displayHelp();
                System.exit(0);
            }
            if (s.equals("-t") || s.equals("--tags")) {
                displayTagList();
                System.exit(0);
            }

             if (s.equals("-a") || s.equals("--all")){
                parseAllFilesInCurrentDirToFiles();
                System.exit(0);
            }
            else {
                parseIndicatedFilesAtArgs(s);
            };
        }
}

static void displayHelp(){
    System.out.println("");
    System.out.println("DICOM Parser APP (c) 2021 SoftCream Software Ltd.");
    System.out.println("http://www.softcream.eu");
    System.out.println("Usage: -h || --help to show help");
    System.out.println("Usage: -a || --all to parse all *.dcm, *.DCM files in current directory & save results to separate data files");
    System.out.println("Usage: -t || --tags to show DICOM tags list");
    System.out.println("Usage: [filename] to parse indicated file & save results do separate data file");
    System.out.println("Example: DICOM-Parser -a ");
    System.out.println("Example: DICOM-Parser test1.dcm ");


}

static void parseIndicatedFilesAtArgs(String filename){

        DicomParser dicomParser = new DicomParser(filename);
        dicomParser.parseIndicatedDicomFileAndSaveDataToOneFile(filename);
    }

static void parseAllFilesInCurrentDirToFiles() throws IOException {

    DicomParser dicomParser = new DicomParser();
    dicomParser.parseAllDicomFilesAndSaveDataToFiles();

}



// Event 1 an option to save tags to specific text file TODO To trash unused
static void saveTagsToFile() {
    DicomTags dicomTags = new DicomTags();
    dicomTags.saveToFile("tags.txt");
}

static void displayTagList() {
    ArrayList taglist = new ArrayList();
    DicomTags dicomTags = new DicomTags();
    taglist = dicomTags.getTags();
    System.out.println("DICOM Parser APP (c) 2021 SoftCream Software Ltd.");
    System.out.println("http://www.softcream.eu");
    System.out.println("DICOM Tags list" +"\n\n\n\n");
    for (Object o: taglist){
        System.out.println(o.toString());
    }
}


}